@@ -18,10 +18,10 @@ class Publisher(Object):
     If an optional parameter is not specified, it should be considered unknown.
     """
 
-    id = Field(str)
-    name = Field(str)
-    cat = Field(Array(str))
-    domain = Field(str)
+    id = Field(unicode)
+    name = Field(unicode)
+    cat = Field(Array(unicode))
+    domain = Field(unicode)
 
 
 class Producer(Object):
@@ -34,10 +34,10 @@ class Producer(Object):
     This object is optional, but useful if the content producer is different from the site publisher.
     """
 
-    id = Field(str)
-    name = Field(str)
-    cat = Field(Array(str))
-    domain = Field(str)
+    id = Field(unicode)
+    name = Field(unicode)
+    cat = Field(Array(unicode))
+    domain = Field(unicode)
 
 
 class Geo(Object):
@@ -54,12 +54,12 @@ class Geo(Object):
 
     lat = Field(float)
     lon = Field(float)
-    country = Field(str)
-    region = Field(str)
-    regionfips104 = Field(str)
-    metro = Field(str)
-    city = Field(str)
-    zip = Field(str)
+    country = Field(unicode)
+    region = Field(unicode)
+    regionfips104 = Field(unicode)
+    metro = Field(unicode)
+    city = Field(unicode)
+    zip = Field(unicode)
     type = Field(constants.LocationType)
 
     def loc(self):
@@ -76,9 +76,9 @@ class Segment(Object):
     if an optional parameter is not specified, it should be considered unknown.
     """
 
-    id = Field(str)
-    name = Field(str)
-    value = Field(str)
+    id = Field(unicode)
+    name = Field(unicode)
+    value = Field(unicode)
 
 
 class Data(Object):
@@ -92,8 +92,8 @@ class Data(Object):
     If an optional parameter is not specified, it should be considered unknown.
     """
 
-    id = Field(str)
-    name = Field(str)
+    id = Field(unicode)
+    name = Field(unicode)
     segment = Field(Array(Segment))
 
 
@@ -109,12 +109,12 @@ class User(Object):
     If device ID is used as a proxy for unique user ID, use the device object.
     """
 
-    id = Field(str)
-    buyerid = Field(str)
+    id = Field(unicode)
+    buyerid = Field(unicode)
     yob = Field(int)
-    gender = Field(str)
-    keywords = Field(str)
-    customdata = Field(str)
+    gender = Field(unicode)
+    keywords = Field(unicode)
+    customdata = Field(unicode)
     geo = Field(Geo)
     data = Field(Array(Data))
 
@@ -132,24 +132,24 @@ class Device(Object):
     """
 
     dnt = Field(int)
-    ua = Field(str)
-    ip = Field(str)
+    ua = Field(unicode)
+    ip = Field(unicode)
     geo = Field(Geo, default=Geo())
-    didsha1 = Field(str)
-    didmd5 = Field(str)
-    dpidsha1 = Field(str)
-    dpidmd5 = Field(str)
-    ipv6 = Field(str)
-    carrier = Field(str)
-    language = Field(str)
-    make = Field(str)
-    model = Field(str)
-    os = Field(str)
-    osv = Field(str)
+    didsha1 = Field(unicode)
+    didmd5 = Field(unicode)
+    dpidsha1 = Field(unicode)
+    dpidmd5 = Field(unicode)
+    ipv6 = Field(unicode)
+    carrier = Field(unicode)
+    language = Field(unicode)
+    make = Field(unicode)
+    model = Field(unicode)
+    os = Field(unicode)
+    osv = Field(unicode)
     js = Field(int)
     connectiontype = Field(constants.ConnectionType)
     devicetype = Field(constants.DeviceType)
-    flashver = Field(str)
+    flashver = Field(unicode)
 
     def is_on_cellular(self):
         return self.connectiontype and self.connectiontype.is_cellular()
@@ -168,18 +168,18 @@ class Content(Object):
     (For example, video impressions embedded in an iframe on an unknown web property or device.)
     """
 
-    id = Field(str)
+    id = Field(unicode)
     episode = Field(int)
-    title = Field(str)
-    series = Field(str)
-    season = Field(str)
-    url = Field(str)
-    cat = Field(Array(str))
+    title = Field(unicode)
+    series = Field(unicode)
+    season = Field(unicode)
+    url = Field(unicode)
+    cat = Field(Array(unicode))
     videoquality = Field(constants.VideoQuality)
-    keywords = Field(str)
-    contentrating = Field(str)
-    userrating = Field(str)
-    context = Field(str)
+    keywords = Field(unicode)
+    contentrating = Field(unicode)
+    userrating = Field(unicode)
+    context = Field(unicode)
     livestream = Field(int)
     sourcerelationship = Field(int)
     producer = Field(Producer)
@@ -196,19 +196,19 @@ class Site(Object):
     At a minimum, it’s useful to provide a page URL or a site ID, but this is not strictly required.
     """
 
-    id = Field(str)
-    name = Field(str)
-    domain = Field(str)
-    cat = Field(Array(str))
-    sectioncat = Field(Array(str))
-    pagecat = Field(Array(str))
-    page = Field(str)
+    id = Field(unicode)
+    name = Field(unicode)
+    domain = Field(unicode)
+    cat = Field(Array(unicode))
+    sectioncat = Field(Array(unicode))
+    pagecat = Field(Array(unicode))
+    page = Field(unicode)
     privacypolicy = Field(int)
-    ref = Field(str)
-    search = Field(str)
+    ref = Field(unicode)
+    search = Field(unicode)
     publisher = Field(Publisher)
     content = Field(Content)
-    keywords = Field(str)
+    keywords = Field(unicode)
 
 
 class App(Object):
@@ -222,19 +222,19 @@ class App(Object):
     At a minimum, it’s useful to provide an App ID or bundle, but this is not strictly required.
     """
 
-    id = Field(str)
-    name = Field(str)
-    domain = Field(str)
-    cat = Field(Array(str))
-    sectioncat = Field(Array(str))
-    pagecat = Field(Array(str))
-    ver = Field(str)
-    bundle = Field(str)
+    id = Field(unicode)
+    name = Field(unicode)
+    domain = Field(unicode)
+    cat = Field(Array(unicode))
+    sectioncat = Field(Array(unicode))
+    pagecat = Field(Array(unicode))
+    ver = Field(unicode)
+    bundle = Field(unicode)
     privacypolicy = Field(int)
     paid = Field(int)
     publisher = Field(Publisher)
     content = Field(Content)
-    keywords = Field(str)
+    keywords = Field(unicode)
 
 
 class Banner(Object):
@@ -252,11 +252,11 @@ class Banner(Object):
 
     w = Field(int)
     h = Field(int)
-    id = Field(str)
+    id = Field(unicode)
     pos = Field(constants.AdPosition)
     btype = Field(Array(constants.BannerType))
     battr = Field(Array(constants.CreativeAttribute))
-    mimes = Field(Array(str))
+    mimes = Field(Array(unicode))
     topframe = Field(int)
     expdir = Field(Array(constants.ExpandableDirection))
     api = Field(Array(constants.APIFramework))
@@ -280,7 +280,7 @@ class Video(Object):
     or if the exchange chooses not to supply the additional information to the bidder.
     """
 
-    mimes = Field(Array(str), required=True)
+    mimes = Field(Array(unicode), required=True)
     linearity = Field(constants.VideoLinearity, required=True)
     minduration = Field(int, required=True)
     maxduration = Field(int, required=True)
@@ -310,15 +310,15 @@ class Impression(Object):
     Each “imp” object has a required ID so that bids can reference them individually.
     """
 
-    id = Field(str, required=True)
+    id = Field(unicode, required=True)
     banner = Field(Banner)
     video = Field(Video)
-    displaymanager = Field(str)
+    displaymanager = Field(unicode)
     instl = Field(int)
-    tagid = Field(str)
+    tagid = Field(unicode)
     bidfloor = Field(Decimal)
-    bidfloorcur = Field(str, default='USD')
-    iframebuster = Field(Array(str))
+    bidfloorcur = Field(unicode, default='USD')
+    iframebuster = Field(Array(unicode))
     ext = Field(Object)
 
 
@@ -330,7 +330,7 @@ class BidRequest(Object):
     Other attributes are optional since an exchange may establish default values.
     """
 
-    id = Field(str, required=True)
+    id = Field(unicode, required=True)
     imp = Field(Array(Impression), required=True)
     site = Field(Site, default=Site())
     app = Field(App, default=App())
@@ -338,11 +338,11 @@ class BidRequest(Object):
     user = Field(User, default=User())
     at = Field(constants.AuctionType, default=constants.AuctionType.SECOND_PRICE)
     tmax = Field(int)
-    wseat = Field(Array(str))
+    wseat = Field(Array(unicode))
     allimpd = Field(int)
-    cur = Field(Array(str))
-    bcat = Field(Array(str))
-    badv = Field(Array(str))
+    cur = Field(Array(unicode))
+    bcat = Field(Array(unicode))
+    badv = Field(Array(unicode))
     ext = Field(Object)
 
     @staticmethod
